@@ -1,20 +1,18 @@
 /* Keyboard Accessibility Status Applet
  * Copyright 2003, 2004 Sun Microsystems Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -118,9 +116,11 @@ static void popup_error_dialog (AccessxStatusApplet        *sapplet);
 
 /* cribbed from geyes */
 static void
-about_cb (GtkAction           *action,
-	  AccessxStatusApplet *sapplet)
+about_cb (GSimpleAction *action,
+          GVariant      *parameter,
+          gpointer       user_data)
 {
+	AccessxStatusApplet *sapplet = (AccessxStatusApplet *) user_data;
         static const gchar *authors [] = {
 		"Calum Benson <calum.benson@sun.com>",
 		"Bill Haneman <bill.haneman@sun.com>",
@@ -146,9 +146,11 @@ about_cb (GtkAction           *action,
 }
 
 static void
-help_cb (GtkAction           *action,
-	 AccessxStatusApplet *sapplet)
+help_cb (GSimpleAction *action,
+         GVariant      *parameter,
+         gpointer       user_data)
 {
+	AccessxStatusApplet *sapplet = (AccessxStatusApplet *) user_data;
 	GError *error = NULL;
 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
@@ -182,9 +184,11 @@ help_cb (GtkAction           *action,
 }
 
 static void
-dialog_cb (GtkAction           *action,
-	   AccessxStatusApplet *sapplet)
+dialog_cb (GSimpleAction *action,
+           GVariant      *parameter,
+           gpointer       user_data)
 {
+	AccessxStatusApplet *sapplet = (AccessxStatusApplet *) user_data;
 	GError *error = NULL;
 	GdkScreen *screen;
 	GdkAppLaunchContext *launch_context;
@@ -196,8 +200,8 @@ dialog_cb (GtkAction           *action,
 	}
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (sapplet->applet));
-	appinfo = g_app_info_create_from_commandline ("gnome-control-center keyboard",
-						      _("Open the keyboard preferences dialog"),
+	appinfo = g_app_info_create_from_commandline ("gnome-control-center universal-access",
+						      _("Open the universal access preferences dialog"),
 						      G_APP_INFO_CREATE_NONE,
 						      &error);
 
@@ -233,16 +237,10 @@ dialog_cb (GtkAction           *action,
 	g_object_unref (appinfo);
 }
 
-static const GtkActionEntry accessx_status_applet_menu_actions [] = {
-	{ "Dialog", GTK_STOCK_PROPERTIES, N_("_Keyboard Accessibility Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (dialog_cb) },
-	{ "Help", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "About", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about_cb) }
+static const GActionEntry accessx_status_applet_menu_actions [] = {
+	{ "dialog", dialog_cb, NULL, NULL, NULL },
+	{ "help",   help_cb,   NULL, NULL, NULL },
+	{ "about",  about_cb,  NULL, NULL, NULL }
 };
 
 static XkbDescPtr 
@@ -1049,7 +1047,6 @@ create_applet (PanelApplet *applet)
 	GtkWidget           *box, *stickyfoo;
 	AtkObject           *atko;
 	GdkPixbuf	    *pixbuf;
-        gint                 large_toolbar_pixels;
 
 	g_set_application_name (_("AccessX Status"));
 
@@ -1063,19 +1060,18 @@ create_applet (PanelApplet *applet)
 	sapplet->orient = panel_applet_get_orient (applet);
 	if (sapplet->orient == PANEL_APPLET_ORIENT_LEFT || 
 	    sapplet->orient == PANEL_APPLET_ORIENT_RIGHT) {
-		box = gtk_vbox_new (FALSE, 0); 
-		stickyfoo = gtk_vbox_new (TRUE, 0);
+		box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		stickyfoo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	}
 	else {
-		box = gtk_hbox_new (FALSE, 0);
-		stickyfoo = gtk_hbox_new (TRUE, 0);
+		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		stickyfoo = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	}
-	large_toolbar_pixels = 24; /* FIXME */
-	if (panel_applet_get_size (sapplet->applet) >= large_toolbar_pixels)
-		icon_size_spec = GTK_ICON_SIZE_LARGE_TOOLBAR;       
-        else 
-		icon_size_spec = GTK_ICON_SIZE_SMALL_TOOLBAR;
-  
+	gtk_box_set_homogeneous (GTK_BOX (stickyfoo), TRUE);
+
+	sapplet->size = 24;
+	icon_size_spec = GTK_ICON_SIZE_LARGE_TOOLBAR;       
+
 	accessx_applet_add_stock_icons (sapplet, box);
 	pixbuf = accessx_status_applet_mousekeys_image (sapplet, NULL);
 	sapplet->mousefoo = gtk_image_new_from_pixbuf (pixbuf);
@@ -1149,27 +1145,39 @@ accessx_status_applet_reorient (GtkWidget *widget, PanelAppletOrient o, gpointer
 
 	if (o == PANEL_APPLET_ORIENT_LEFT || 
 	    o == PANEL_APPLET_ORIENT_RIGHT) {
-		box = gtk_vbox_new (FALSE, 0); 
-		stickyfoo = gtk_vbox_new (TRUE, 0);
+		box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		stickyfoo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	}
 	else {
-		box = gtk_hbox_new (FALSE, 0);
-		stickyfoo = gtk_hbox_new (TRUE, 0);
+		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		stickyfoo = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	}
+	gtk_box_set_homogeneous (GTK_BOX (stickyfoo), TRUE);
 	accessx_status_applet_layout_box (sapplet, box, stickyfoo);
 }
 
 static void
-accessx_status_applet_resize (GtkWidget *widget, int size, gpointer user_data)
+accessx_status_applet_resize (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data)
 {
-	; /* TODO: either rescale icons to fit panel, or tile them when possible */
+	AccessxStatusApplet *sapplet = (AccessxStatusApplet *) user_data;
+	gint old_size = sapplet->size;
+
+	if (sapplet->orient == PANEL_APPLET_ORIENT_LEFT || sapplet->orient == PANEL_APPLET_ORIENT_RIGHT) {
+		sapplet->size = allocation->width;
+	} else {
+		sapplet->size = allocation->height;
+	}
+
+	if (sapplet->size != old_size) {
+		/* TODO: either rescale icons to fit panel, or tile them when possible */
+	}
 }
 
 static gboolean
 button_press_cb (GtkWidget *widget, GdkEventButton *event, AccessxStatusApplet *sapplet)
 {
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) 
-		dialog_cb (NULL, sapplet);
+		dialog_cb (NULL, NULL, sapplet);
 
 	return FALSE;
 }
@@ -1184,7 +1192,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, AccessxStatusApplet *sapple
 	case GDK_KEY_Return:
 	case GDK_KEY_space:
 	case GDK_KEY_KP_Space:
-		dialog_cb (NULL, sapplet);
+		dialog_cb (NULL, NULL, sapplet);
 		return TRUE;
 
 	default:
@@ -1239,7 +1247,8 @@ accessx_status_applet_fill (PanelApplet *applet)
 {
 	AccessxStatusApplet *sapplet;
 	AtkObject           *atk_object;
-	GtkActionGroup      *action_group;
+	GSimpleActionGroup  *action_group;
+	GAction             *action;
 	gchar               *ui_path;
 	gboolean was_realized = FALSE;
 
@@ -1257,7 +1266,7 @@ accessx_status_applet_fill (PanelApplet *applet)
 	g_object_connect (sapplet->applet,
 			  "signal::destroy", accessx_status_applet_destroy, sapplet,
 			  "signal::change_orient", accessx_status_applet_reorient, sapplet,
-			  "signal::change_size", accessx_status_applet_resize, sapplet,
+			  "signal::size-allocate", accessx_status_applet_resize, sapplet,
 			  NULL);
 			  
 	g_signal_connect (sapplet->applet, "button_press_event",
@@ -1265,22 +1274,22 @@ accessx_status_applet_fill (PanelApplet *applet)
 	g_signal_connect (sapplet->applet, "key_press_event",
 				   G_CALLBACK (key_press_cb), sapplet);				   
 
-	action_group = gtk_action_group_new ("Accessx Applet Actions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (action_group,
-				      accessx_status_applet_menu_actions,
-				      G_N_ELEMENTS (accessx_status_applet_menu_actions),
-				      sapplet);
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 accessx_status_applet_menu_actions,
+	                                 G_N_ELEMENTS (accessx_status_applet_menu_actions),
+	                                 sapplet);
 	ui_path = g_build_filename (ACCESSX_MENU_UI_DIR, "accessx-status-applet-menu.xml", NULL);
-	panel_applet_setup_menu_from_file (sapplet->applet, ui_path, action_group);
+	panel_applet_setup_menu_from_file (sapplet->applet, ui_path, action_group, GETTEXT_PACKAGE);
 	g_free (ui_path);
 
-	if (panel_applet_get_locked_down (sapplet->applet)) {
-		GtkAction *action;
+	gtk_widget_insert_action_group (GTK_WIDGET (applet), "accessx",
+	                                G_ACTION_GROUP (action_group));
+
+	action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "dialog");
+	g_object_bind_property (applet, "locked-down", action, "enabled",
+                            G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		action = gtk_action_group_get_action (action_group, "Dialog");
-		gtk_action_set_visible (action, FALSE);
-	}
 	g_object_unref (action_group);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (sapplet->applet), _("Keyboard Accessibility Status"));
