@@ -112,25 +112,6 @@ static const gunichar * const chartable[] = {
 	af_ZA_code
 };
 
-gboolean
-key_writable (PanelApplet *applet, const char *key)
-{
-	gboolean writable;
-	char *fullkey;
-	static GConfClient *client = NULL;
-	if (client == NULL)
-		client = gconf_client_get_default ();
-
-	fullkey = panel_applet_gconf_get_full_key (applet, key);
-
-	writable = gconf_client_key_is_writable (client, fullkey, NULL);
-
-	g_free (fullkey);
-
-	return writable;
-}
-
-
 /* sets the picked character as the selection when it gets a request */
 static void
 charpick_selection_handler(GtkWidget *widget,
@@ -299,8 +280,8 @@ menuitem_activated (GtkMenuItem *menuitem, charpick_data *curr_data)
 	
 	curr_data->charlist = string;
 	build_table (curr_data);
-	if (key_writable (applet, "current_list"))
-		panel_applet_gconf_set_string (applet, "current_list", curr_data->charlist, NULL);
+	if (g_settings_is_writable (curr_data->settings, KEY_CURRENT_LIST))
+		g_settings_set_string (curr_data->settings, KEY_CURRENT_LIST, curr_data->charlist);
 }
 
 void
@@ -426,9 +407,9 @@ build_table(charpick_data *p_curr_data)
     gtk_widget_destroy(p_curr_data->box);
     
   if (p_curr_data->panel_vertical)
-    box = gtk_vbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   else 
-    box = gtk_hbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (box);
   p_curr_data->box = box;
   
@@ -515,10 +496,10 @@ build_table(charpick_data *p_curr_data)
   
   if (p_curr_data->panel_vertical) {
     size_ratio = p_curr_data->panel_size / max_width;
-    button_box = gtk_hbox_new (TRUE, 0);
+    button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   } else {
     size_ratio = p_curr_data->panel_size / max_height;
-    button_box = gtk_vbox_new (TRUE, 0);
+    button_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   }
 
   gtk_box_pack_start (GTK_BOX (box), button_box, TRUE, TRUE, 0);
@@ -526,9 +507,10 @@ build_table(charpick_data *p_curr_data)
   size_ratio = MAX (size_ratio, 1);
   row_box = g_new0 (GtkWidget *, size_ratio);
   for (i=0; i < size_ratio; i++) {
-  	if (!p_curr_data->panel_vertical) row_box[i] = gtk_hbox_new (TRUE, 0);
-  	else row_box[i] = gtk_vbox_new (TRUE, 0);
-  	gtk_box_pack_start (GTK_BOX (button_box), row_box[i], TRUE, TRUE, 0);
+    if (!p_curr_data->panel_vertical) row_box[i] = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+    else row_box[i] = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_box_set_homogeneous (GTK_BOX (button_box), TRUE);
+    gtk_box_pack_start (GTK_BOX (button_box), row_box[i], TRUE, TRUE, 0);
   }
   
   for (i = 0; i <len; i++) {  	
@@ -585,9 +567,12 @@ static void applet_change_orient(PanelApplet *applet, PanelAppletOrient o, gpoin
 
 
 static void
-about (GtkAction     *action,
-       charpick_data *curr_data)
+about (GSimpleAction *action,
+       GVariant      *parameter,
+       gpointer       user_data)
 {
+  charpick_data *curr_data = (charpick_data *) user_data;
+
   static const char * const authors[] = {
 	  "Alexandre Muñiz <munizao@xprt.net>",
 	  "Kevin Vandersloot",
@@ -616,9 +601,11 @@ about (GtkAction     *action,
 
 
 static void
-help_cb (GtkAction     *action,
-	 charpick_data *curr_data)
+help_cb (GSimpleAction *action,
+         GVariant      *parameter,
+         gpointer       user_data)
 {
+  charpick_data *curr_data = (charpick_data *) user_data;
   GError *error = NULL;
 
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (curr_data->applet)),
@@ -648,6 +635,8 @@ applet_destroy (GtkWidget *widget, gpointer data)
     gtk_widget_destroy (curr_data->box);
   if (curr_data->menu)
     gtk_widget_destroy (curr_data->menu);
+  if (curr_data->settings)
+    g_object_unref (curr_data->settings);
   g_free (curr_data);
   
 }
@@ -655,48 +644,29 @@ applet_destroy (GtkWidget *widget, gpointer data)
 void 
 save_chartable (charpick_data *curr_data)
 {
-	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
-	GConfValue *value;
 	GList *list = curr_data->chartable;
-	GSList *slist = NULL;
-	
+	GArray *array = g_array_new (TRUE, TRUE, sizeof (gchar *));
+
 	while (list) {
-		gchar *charlist = list->data;
-		GConfValue *v1;
-		v1 = gconf_value_new_from_string (GCONF_VALUE_STRING, charlist, NULL);
-		slist = g_slist_append (slist, v1);
-		list = g_list_next (list);
+		array = g_array_append_val (array, list->data);
+		list = list->next;
 	}
-	
-	value = gconf_value_new (GCONF_VALUE_LIST);
-	gconf_value_set_list_type (value, GCONF_VALUE_STRING);
-	gconf_value_set_list_nocopy (value, slist);
-	panel_applet_gconf_set_value (applet, "chartable", value, NULL);
-	gconf_value_free (value);
+
+	g_settings_set_strv (curr_data->settings, KEY_CHARTABLE, (const gchar **) array->data);
+	g_array_free (array, TRUE);
 }
 
 static void
 get_chartable (charpick_data *curr_data)
 {
-	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
-	GConfValue *value;
-	gint i, n;
-	
-	value = panel_applet_gconf_get_value (applet, "chartable", NULL);
-	if (value) {
-		GSList *slist = gconf_value_get_list (value);
-		while (slist) {
-			GConfValue *v1 = slist->data;
-			gchar *charlist;
-			
-			charlist = g_strdup (gconf_value_get_string (v1));
-			curr_data->chartable = g_list_append (curr_data->chartable, charlist);
-			
-			slist = g_slist_next (slist);
+	gchar **value = g_settings_get_strv (curr_data->settings, KEY_CHARTABLE);
+	gint i, n = 0;
+
+	if (value[0]) {
+		for (i = 0; value[i] != NULL; i++) {
+			curr_data->chartable = g_list_append (curr_data->chartable, g_strdup (value[i]));
 		}
-		gconf_value_free (value);
-	}
-	else {
+	} else {
 		n = G_N_ELEMENTS (chartable);
 		for (i=0; i<n; i++) {
 			gchar *string;
@@ -705,23 +675,17 @@ get_chartable (charpick_data *curr_data)
 			curr_data->chartable = g_list_append (curr_data->chartable, string);
 		
 		}
-		if ( ! key_writable (PANEL_APPLET (curr_data->applet), "chartable"))
+		if (g_settings_is_writable (curr_data->settings, KEY_CHARTABLE))
 			save_chartable (curr_data);
 	}
-	
 
+	g_strfreev (value);
 }
 
-static const GtkActionEntry charpick_applet_menu_actions [] = {
-	{ "Preferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (show_preferences_dialog) },
-	{ "Help", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "About", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about) }
+static const GActionEntry charpick_applet_menu_actions [] = {
+	{ "preferences", show_preferences_dialog, NULL, NULL, NULL },
+	{ "help",        help_cb,                 NULL, NULL, NULL },
+	{ "about",       about,                   NULL, NULL, NULL }
 };
 
 void
@@ -753,7 +717,8 @@ charpicker_applet_fill (PanelApplet *applet)
   GdkAtom utf8_atom;
   GList *list;
   gchar *string;
-  GtkActionGroup *action_group;
+  GSimpleActionGroup *action_group;
+  GAction *action;
   gchar *ui_path;
 
   g_set_application_name (_("Character Palette"));
@@ -762,7 +727,6 @@ charpicker_applet_fill (PanelApplet *applet)
 
   panel_applet_set_background_widget (applet, GTK_WIDGET (applet));
 
-  panel_applet_add_preferences (applet, "/schemas/apps/charpick/prefs", NULL);
   panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
    
   curr_data = g_new0 (charpick_data, 1);
@@ -770,11 +734,12 @@ charpicker_applet_fill (PanelApplet *applet)
   curr_data->applet = GTK_WIDGET (applet);
   curr_data->about_dialog = NULL;
   curr_data->add_edit_dialog = NULL;
+  curr_data->settings = panel_applet_settings_new (applet, CHARPICK_SCHEMA);
  
   get_chartable (curr_data);
   
-  string  = panel_applet_gconf_get_string (applet, "current_list", NULL);
-  if (string) {
+  string = g_settings_get_string (curr_data->settings, KEY_CURRENT_LIST);
+  if (string[0] != '\0') {
   	list = curr_data->chartable;
   	while (list) {
   		if (g_ascii_strcasecmp (list->data, string) == 0)
@@ -791,9 +756,7 @@ charpicker_applet_fill (PanelApplet *applet)
   } else {
   	curr_data->charlist = curr_data->chartable->data;  
   }
- 
-  curr_data->panel_size = panel_applet_get_size (applet);
-  
+
   orientation = panel_applet_get_orient (applet);
   curr_data->panel_vertical = (orientation == PANEL_APPLET_ORIENT_LEFT) 
                               || (orientation == PANEL_APPLET_ORIENT_RIGHT);
@@ -832,23 +795,24 @@ charpicker_applet_fill (PanelApplet *applet)
   
   gtk_widget_show_all (GTK_WIDGET (applet));
 
-  action_group = gtk_action_group_new ("Charpicker Applet Actions");
-  gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-  gtk_action_group_add_actions (action_group,
-				charpick_applet_menu_actions,
-				G_N_ELEMENTS (charpick_applet_menu_actions),
-				curr_data);
+  action_group = g_simple_action_group_new ();
+  g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+                                   charpick_applet_menu_actions,
+                                   G_N_ELEMENTS (charpick_applet_menu_actions),
+                                   curr_data);
   ui_path = g_build_filename (CHARPICK_MENU_UI_DIR, "charpick-applet-menu.xml", NULL);
-  panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-                                     ui_path, action_group);
+  panel_applet_setup_menu_from_file (applet,
+                                     ui_path, action_group,
+                                     GETTEXT_PACKAGE);
   g_free (ui_path);
 
-  if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
-	  GtkAction *action;
+  gtk_widget_insert_action_group (GTK_WIDGET (applet), "charpick",
+	                              G_ACTION_GROUP (action_group));
+
+  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+  g_object_bind_property (applet, "locked-down", action, "enabled",
+                          G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-	  action = gtk_action_group_get_action (action_group, "Preferences");
-	  gtk_action_set_visible (action, FALSE);
-  }
   g_object_unref (action_group);
 
   register_stock_for_edit ();			             
