@@ -106,11 +106,11 @@ add_edit_dialog_create (charpick_data *curr_data, gchar *string, gchar *title)
 
 	dbox = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	
-	vbox = gtk_vbox_new (FALSE, 12);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 	gtk_box_pack_start (GTK_BOX (dbox), vbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 	
 	label = gtk_label_new_with_mnemonic (_("_Palette:"));
@@ -161,10 +161,8 @@ add_palette_cb (GtkDialog *dialog, int response_id, charpick_data *curr_data)
 		curr_data->charlist = curr_data->chartable->data;
 		build_table (curr_data);
 
-		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
-			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet),
-						      "current_list", 
-					  	       curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, KEY_CURRENT_LIST))
+			g_settings_set_string (curr_data->settings, KEY_CURRENT_LIST, curr_data->charlist);
 	}
 
 	save_chartable (curr_data);
@@ -225,8 +223,8 @@ edit_palette_cb (GtkDialog *dialog, int response_id, charpick_data *curr_data)
 		curr_data->charlist = new;
 		build_table (curr_data);
 
-		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
-			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet), "current_list", curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, KEY_CURRENT_LIST))
+			g_settings_set_string (curr_data->settings, KEY_CURRENT_LIST, curr_data->charlist);
 	}
 	
 	g_free (charlist);
@@ -314,8 +312,8 @@ delete_palette (GtkButton *button, charpick_data *curr_data)
 	if (g_ascii_strcasecmp (curr_data->charlist, charlist) == 0) {
 		curr_data->charlist = curr_data->chartable != NULL ? 
 				      curr_data->chartable->data : "";
-		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
-			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet), "current_list", curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, KEY_CURRENT_LIST))
+			g_settings_set_string (curr_data->settings, KEY_CURRENT_LIST, curr_data->charlist);
 	}
 	g_free (charlist);
 	
@@ -410,7 +408,7 @@ create_hig_catagory (GtkWidget *main_box, gchar *title)
 	GtkWidget *label;
 	gchar *tmp;
 		
-	vbox = gtk_vbox_new (FALSE, 6);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_box_pack_start (GTK_BOX (main_box), vbox, TRUE, TRUE, 0);
 
 	tmp = g_strdup_printf ("<b>%s</b>", title);
@@ -420,13 +418,13 @@ create_hig_catagory (GtkWidget *main_box, gchar *title)
 	g_free (tmp);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 	
 	label = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
-	vbox2 = gtk_vbox_new (FALSE, 6);
+	vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
 
 	return vbox2;
@@ -444,13 +442,13 @@ static void default_chars_frame_create(charpick_data *curr_data)
 
   dbox = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
-  vbox = gtk_vbox_new (FALSE, 18);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
   gtk_box_pack_start (GTK_BOX (dbox), vbox, TRUE, TRUE, 0);
 
   vbox1 = create_hig_catagory (vbox, _("Character Palette")); 
   
-  vbox3 = gtk_vbox_new (FALSE, 6);
+  vbox3 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (vbox1), vbox3, TRUE, TRUE, 0);
   
   label = gtk_label_new_with_mnemonic(_("_Palettes:"));
@@ -458,12 +456,12 @@ static void default_chars_frame_create(charpick_data *curr_data)
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show(label);
 	  
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_box_pack_start (GTK_BOX (vbox3), hbox, TRUE, TRUE, 0); 
   scrolled = create_palettes_tree (curr_data, label);
   gtk_box_pack_start (GTK_BOX (hbox), scrolled, TRUE, TRUE, 0);
   
-  vbox2 = gtk_vbox_new (FALSE, 6);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (hbox), vbox2, FALSE, FALSE, 0);
   button = gtk_button_new_from_stock (GTK_STOCK_ADD);
   gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, FALSE, 0);
@@ -488,7 +486,7 @@ static void default_chars_frame_create(charpick_data *curr_data)
   set_access_namedesc (button, _("Delete button"),
 				         _("Click to delete the selected palette"));
 
-  if ( ! key_writable (PANEL_APPLET (curr_data->applet), "chartable"))
+  if (!g_settings_is_writable (curr_data->settings, KEY_CHARTABLE))
 	  gtk_widget_set_sensitive (vbox3, FALSE);
    
   return;
@@ -527,9 +525,12 @@ response_cb (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-show_preferences_dialog (GtkAction     *action,
-			 charpick_data *curr_data)
+show_preferences_dialog (GSimpleAction *action,
+                         GVariant      *parameter,
+                         gpointer       user_data)
 {
+  charpick_data *curr_data = (charpick_data *) user_data;
+
   if (curr_data->propwindow) {
     gtk_window_set_screen (GTK_WINDOW (curr_data->propwindow),
 			   gtk_widget_get_screen (curr_data->applet));
