@@ -12,9 +12,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *  General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors : Carlos García Campos <carlosgc@gnome.org>
  */
@@ -26,7 +25,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <panel-applet.h>
-#include <panel-applet-gconf.h>
 #include <glib/gi18n.h>
 #include <stdlib.h>
 #include <string.h>
@@ -79,12 +77,15 @@ struct _CPUFreqAppletClass {
 static void     cpufreq_applet_init              (CPUFreqApplet      *applet);
 static void     cpufreq_applet_class_init        (CPUFreqAppletClass *klass);
 
-static void     cpufreq_applet_preferences_cb    (GtkAction          *action,
-                                                  CPUFreqApplet      *applet);
-static void     cpufreq_applet_help_cb           (GtkAction          *action,
-                                                  CPUFreqApplet      *applet);
-static void     cpufreq_applet_about_cb          (GtkAction          *action,
-                                                  CPUFreqApplet      *applet);
+static void     cpufreq_applet_preferences_cb    (GSimpleAction *action,
+                                                  GVariant      *parameter,
+                                                  gpointer       user_data);
+static void     cpufreq_applet_help_cb           (GSimpleAction *action,
+                                                  GVariant      *parameter,
+                                                  gpointer       user_data);
+static void     cpufreq_applet_about_cb          (GSimpleAction *action,
+                                                  GVariant      *parameter,
+                                                  gpointer       user_data);
 
 static void     cpufreq_applet_pixmap_set_image  (CPUFreqApplet      *applet,
                                                   gint                perc);
@@ -119,16 +120,10 @@ static const gchar *const cpufreq_icons[] = {
         NULL
 };
 
-static const GtkActionEntry cpufreq_applet_menu_actions[] = {
-	{ "CPUFreqAppletPreferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (cpufreq_applet_preferences_cb) },
-	{ "CPUFreqAppletHelp", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (cpufreq_applet_help_cb) },
-	{ "CPUFreqAppletAbout", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (cpufreq_applet_about_cb) }
+static const GActionEntry cpufreq_applet_menu_actions [] = {
+	{ "preferences", cpufreq_applet_preferences_cb, NULL, NULL, NULL },
+	{ "help",        cpufreq_applet_help_cb,        NULL, NULL, NULL },
+	{ "about",       cpufreq_applet_about_cb,       NULL, NULL, NULL }
 };
 
 G_DEFINE_TYPE (CPUFreqApplet, cpufreq_applet, PANEL_TYPE_APPLET)
@@ -192,7 +187,6 @@ cpufreq_applet_init (CPUFreqApplet *applet)
         panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
 	panel_applet_set_background_widget (PANEL_APPLET (applet), GTK_WIDGET (applet));
 
-        applet->size = panel_applet_get_size (PANEL_APPLET (applet));
         applet->orient = panel_applet_get_orient (PANEL_APPLET (applet));
 
 	switch (applet->orient) {
@@ -397,7 +391,7 @@ cpufreq_applet_get_preferred_width (GtkWidget *widget,
 		gint icon_width;
 
                 gtk_widget_get_preferred_width (applet->icon, &icon_width, NULL);
-		width = GTK_IS_HBOX (applet->box) ?
+		width = gtk_orientable_get_orientation (GTK_ORIENTABLE (applet->box)) == GTK_ORIENTATION_HORIZONTAL ?
 			labels_width + icon_width + 2 :
 			MAX (labels_width, icon_width + 2);
 	} else {
@@ -557,17 +551,21 @@ cpufreq_applet_change_orient (PanelApplet *pa, PanelAppletOrient orient)
 }
 
 static void
-cpufreq_applet_preferences_cb (GtkAction     *action,
-                               CPUFreqApplet *applet)
+cpufreq_applet_preferences_cb (GSimpleAction *action,
+                               GVariant      *parameter,
+                               gpointer       user_data)
 {
+	CPUFreqApplet *applet = (CPUFreqApplet *) user_data;
         cpufreq_preferences_dialog_run (applet->prefs,
                                         gtk_widget_get_screen (GTK_WIDGET (applet)));
 }
 
 static void
-cpufreq_applet_help_cb (GtkAction     *action,
-                        CPUFreqApplet *applet)
+cpufreq_applet_help_cb (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
+	CPUFreqApplet *applet = (CPUFreqApplet *) user_data;
         GError *error = NULL;
            
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
@@ -583,8 +581,9 @@ cpufreq_applet_help_cb (GtkAction     *action,
 }
 
 static void
-cpufreq_applet_about_cb (GtkAction     *action,
-                         CPUFreqApplet *applet)
+cpufreq_applet_about_cb (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
         static const gchar *const authors[] = {
                 "Carlos Garcia Campos <carlosgc@gnome.org>",
@@ -880,21 +879,21 @@ cpufreq_applet_refresh (CPUFreqApplet *applet)
         }
 
 	if (horizontal) {
-		applet->labels_box = gtk_hbox_new (FALSE, 2);
+		applet->labels_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 		if ((label_size + pixmap_size) <= panel_size)
-			applet->box = gtk_vbox_new (FALSE, 2);
+			applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
 		else
-			applet->box = gtk_hbox_new (FALSE, 2);
+			applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 	} else {
                 if (total_size <= panel_size) {
-                        applet->box = gtk_hbox_new (FALSE, 2);
-                        applet->labels_box  = gtk_hbox_new (FALSE, 2);
+                        applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+                        applet->labels_box  = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
                 } else if ((label_size + unit_label_size) <= (panel_size - size_step)) {
-                        applet->box = gtk_vbox_new (FALSE, 2);
-                        applet->labels_box  = gtk_hbox_new (FALSE, 2);
+                        applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+                        applet->labels_box  = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
                 } else {
-                        applet->box = gtk_vbox_new (FALSE, 2);
-                        applet->labels_box  = gtk_vbox_new (FALSE, 2);
+                        applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+                        applet->labels_box  = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
                 }
 	}
 
@@ -936,25 +935,22 @@ cpufreq_applet_prefs_show_mode_changed (CPUFreqPrefs  *prefs,
 static void
 cpufreq_applet_setup (CPUFreqApplet *applet)
 {
-	GtkActionGroup *action_group;
+	GSimpleActionGroup *action_group;
+	GAction *action;
 	gchar          *ui_path;
-        AtkObject      *atk_obj;
-        gchar          *prefs_key;
+	AtkObject      *atk_obj;
+	GSettings *settings;
 
 	g_set_application_name  (_("CPU Frequency Scaling Monitor"));
 
 	gtk_window_set_default_icon_name ("gnome-cpu-frequency-applet");
-	
-        panel_applet_add_preferences (PANEL_APPLET (applet),
-                                      "/schemas/apps/cpufreq-applet/prefs", NULL);
-           
+
         /* Preferences */
         if (applet->prefs)
                 g_object_unref (applet->prefs);
-        
-        prefs_key = panel_applet_get_preferences_key (PANEL_APPLET (applet));
-        applet->prefs = cpufreq_prefs_new (prefs_key);
-        g_free (prefs_key);
+
+        settings = panel_applet_settings_new (PANEL_APPLET (applet), "org.gnome.gnome-applets.cpufreq");
+        applet->prefs = cpufreq_prefs_new (settings);
 
 	g_signal_connect (G_OBJECT (applet->prefs),
 			  "notify::cpu",
@@ -978,23 +974,24 @@ cpufreq_applet_setup (CPUFreqApplet *applet)
                                   (gpointer) applet);
            
         /* Setup the menus */
-	action_group = gtk_action_group_new ("CPUFreq Applet Actions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (action_group,
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
 				      cpufreq_applet_menu_actions,
 				      G_N_ELEMENTS (cpufreq_applet_menu_actions),
 				      applet);
 	ui_path = g_build_filename (CPUFREQ_MENU_UI_DIR, "cpufreq-applet-menu.xml", NULL);
         panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-					   ui_path, action_group);
+					   ui_path, action_group,
+					   GETTEXT_PACKAGE);
 	g_free (ui_path);
 
-        if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
-		GtkAction *action;
+	gtk_widget_insert_action_group (GTK_WIDGET (applet), "cpufreq",
+	                                G_ACTION_GROUP (action_group));
+
+    action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+	g_object_bind_property (applet, "locked-down", action, "enabled",
+                          G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		action = gtk_action_group_get_action (action_group, "CPUFreqPreferences");
-		gtk_action_set_visible (action, FALSE);
-        }
 	g_object_unref (action_group);
 
         atk_obj = gtk_widget_get_accessible (GTK_WIDGET (applet));
