@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author:
  *   James Henstridge <jamesh@canonical.com>
@@ -30,7 +29,6 @@
 #include "drive-button.h"
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gconf/gconf-client.h>
 
 #include <string.h>
 
@@ -41,8 +39,6 @@ enum {
     CMD_EJECT
 };
 
-#define GCONF_ROOT_AUTOPLAY  "/desktop/gnome/volume_manager/"
-
 /* type registration boilerplate code */
 G_DEFINE_TYPE(DriveButton, drive_button, GTK_TYPE_BUTTON)
 
@@ -823,34 +819,21 @@ eject_drive (DriveButton *self, GtkWidget *item)
     }
 }
 static void
-play_autoplay_media (DriveButton *self, const char *autoplay_key, 
-		     const char *dflt)
+play_autoplay_media (DriveButton *self, const char *dflt)
 {
-	GConfClient *gconf_client = gconf_client_get_default ();
-	char *command = gconf_client_get_string (gconf_client,
-			autoplay_key, NULL);
-
-	if (!command)
-	    command = g_strdup (dflt);
-
-	run_command (self, command);
-
-	g_free (command);
-	g_object_unref (gconf_client);
+	run_command (self, dflt);
 }
 
 static void
 play_dvd (DriveButton *self, GtkWidget *item)
 {
-        play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_dvd_command",
-			     "totem %d");
+        play_autoplay_media (self, "totem %d");
 }
 
 static void
 play_cda (DriveButton *self, GtkWidget *item)
 {
-        play_autoplay_media (self, GCONF_ROOT_AUTOPLAY "autoplay_cda_command",
-			     "sound-juicer -d %d");
+        play_autoplay_media (self, "sound-juicer -d %d");
 }
 
 static void
