@@ -1,13 +1,18 @@
-/* $Id$ */
-
 /*
- *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
+ * Copyright (C) Papadimitriou Spiros <spapadim+@cs.cmu.edu>
  *
- *  This code released under the GNU GPL.
- *  Read the file COPYING for more information.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  Main applet widget
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,12 +37,6 @@
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 
-#ifdef HAVE_NETWORKMANAGER
-#include <dbus/dbus-glib.h>
-#include <dbus/dbus-glib-lowlevel.h>
-#include <NetworkManager/NetworkManager.h>
-#endif
-
 #include "gweather.h"
 #include "gweather-about.h"
 #include "gweather-pref.h"
@@ -48,16 +47,19 @@
 
 static void update_finish (GWeatherInfo *info, gpointer data);
 
-static void about_cb (GtkAction      *action,
-		      GWeatherApplet *gw_applet)
+static void about_cb (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
 {
-
+	GWeatherApplet *gw_applet = (GWeatherApplet *) user_data;
     gweather_about_run (gw_applet);
 }
 
-static void help_cb (GtkAction      *action,
-		     GWeatherApplet *gw_applet)
+static void help_cb (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
 {
+	GWeatherApplet *gw_applet = (GWeatherApplet *) user_data;
     GError *error = NULL;
 
     gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
@@ -77,9 +79,12 @@ static void help_cb (GtkAction      *action,
     }
 }
 
-static void pref_cb (GtkAction      *action,
-		     GWeatherApplet *gw_applet)
+static void pref_cb (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
 {
+   GWeatherApplet *gw_applet = (GWeatherApplet *) user_data;
+
    if (gw_applet->pref_dialog) {
 	gtk_window_present (GTK_WINDOW (gw_applet->pref_dialog));
    } else {
@@ -90,9 +95,12 @@ static void pref_cb (GtkAction      *action,
    }
 }
 
-static void details_cb (GtkAction      *action,
-			GWeatherApplet *gw_applet)
+static void details_cb (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
+   GWeatherApplet *gw_applet = (GWeatherApplet *) user_data;
+
    if (gw_applet->details_dialog) {
 	gtk_window_present (GTK_WINDOW (gw_applet->details_dialog));
    } else {
@@ -104,29 +112,20 @@ static void details_cb (GtkAction      *action,
    }
 }
 
-static void update_cb (GtkAction      *action,
-		       GWeatherApplet *gw_applet)
+static void update_cb (GSimpleAction *action,
+                       GVariant      *parameter,
+                       gpointer       user_data)
 {
+	GWeatherApplet *gw_applet = (GWeatherApplet *) user_data;
     gweather_update (gw_applet);
 }
 
-
-static const GtkActionEntry weather_applet_menu_actions [] = {
-	{ "Details", NULL, N_("_Details"),
-	  NULL, NULL,
-	  G_CALLBACK (details_cb) },
-	{ "Update", GTK_STOCK_REFRESH, N_("_Update"),
-	  NULL, NULL,
-	  G_CALLBACK (update_cb) },
-	{ "Props", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (pref_cb) },
-	{ "Help", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "About", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about_cb) }
+static const GActionEntry weather_applet_menu_actions [] = {
+	{ "details",     details_cb, NULL, NULL, NULL },
+	{ "update",      update_cb,  NULL, NULL, NULL },
+	{ "preferences", pref_cb,    NULL, NULL, NULL },
+	{ "help",        help_cb,    NULL, NULL, NULL },
+	{ "about",       about_cb,   NULL, NULL, NULL }
 };
 
 static void place_widgets (GWeatherApplet *gw_applet)
@@ -159,7 +158,7 @@ static void place_widgets (GWeatherApplet *gw_applet)
 
     if (icon_name != NULL) {
         gtk_widget_show (gw_applet->image);
-        gtk_widget_size_request(gw_applet->image, &req);
+        gtk_widget_get_preferred_size(gw_applet->image, &req, NULL);
         if (horizontal)
             total_size += req.height;
         else
@@ -177,7 +176,7 @@ static void place_widgets (GWeatherApplet *gw_applet)
 
     /* Check the label size to determine box layout */
     gtk_widget_show (gw_applet->label);
-    gtk_widget_size_request(gw_applet->label, &req);
+    gtk_widget_get_preferred_size(gw_applet->label, &req, NULL);
     if (horizontal)
         total_size += req.height;
     else
@@ -186,15 +185,15 @@ static void place_widgets (GWeatherApplet *gw_applet)
     /* Pack the box */
     if (gw_applet->box)
         gtk_widget_destroy (gw_applet->box);
-    
+
     if (horizontal && (total_size <= panel_size))
-        gw_applet->box = gtk_vbox_new(FALSE, 0);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     else if (horizontal && (total_size > panel_size))
-        gw_applet->box = gtk_hbox_new(FALSE, 2);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     else if (!horizontal && (total_size <= panel_size))
-        gw_applet->box = gtk_hbox_new(FALSE, 2);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     else 
-        gw_applet->box = gtk_vbox_new(FALSE, 0);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
     /* Rebuild the applet it's visual area */
     gtk_container_add (GTK_CONTAINER (gw_applet->container), gw_applet->box);
@@ -240,7 +239,7 @@ static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data
 
     if (ev->type == GDK_BUTTON_PRESS) {
 	if (!gw_applet->details_dialog)
-		details_cb (NULL, gw_applet);
+		details_cb (NULL, NULL, gw_applet);
 	else
 		gtk_widget_destroy (GTK_WIDGET (gw_applet->details_dialog));
 	
@@ -262,7 +261,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 		break;
 	case GDK_KEY_d:
 		if (event->state == GDK_CONTROL_MASK) {
-			details_cb (NULL, gw_applet);
+			details_cb (NULL, NULL, gw_applet);
 			return TRUE;
 		}
 		break;		
@@ -272,7 +271,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 	case GDK_KEY_Return:
 	case GDK_KEY_space:
 	case GDK_KEY_KP_Space:
-		details_cb (NULL, gw_applet);
+		details_cb (NULL, NULL, gw_applet);
 		return TRUE;
 	default:
 		break;
@@ -282,9 +281,20 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 
 }
 
+
+static void
+network_changed (GNetworkMonitor *monitor, gboolean available, GWeatherApplet *gw_applet)
+{
+    if (available) {
+        gweather_update (gw_applet);
+    }
+}
+
 static void
 applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
 {
+    GNetworkMonitor *monitor;
+
     if (gw_applet->pref_dialog)
        gtk_widget_destroy (gw_applet->pref_dialog);
 
@@ -304,19 +314,22 @@ applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
     g_clear_object (&gw_applet->lib_settings);
     g_clear_object (&gw_applet->applet_settings);
 
+    monitor = g_network_monitor_get_default ();
+    g_signal_handlers_disconnect_by_func (monitor,
+                                          G_CALLBACK (network_changed),
+                                          gw_applet);
+
     gweather_info_abort (gw_applet->gweather_info);
 }
 
-#ifdef HAVE_NETWORKMANAGER
-static void setup_network_monitor (GWeatherApplet *gw_applet);
-#endif
-
 void gweather_applet_create (GWeatherApplet *gw_applet)
 {
-    GtkActionGroup *action_group;
+    GSimpleActionGroup *action_group;
+    GAction *action;
     gchar          *ui_path;
     AtkObject      *atk_obj;
     GWeatherForecastType type;
+    GNetworkMonitor*monitor;
 
     panel_applet_set_flags (gw_applet->applet, PANEL_APPLET_EXPAND_MINOR);
 
@@ -347,27 +360,26 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     if (GTK_IS_ACCESSIBLE (atk_obj))
 	   atk_object_set_name (atk_obj, _("GNOME Weather"));
 
-    gw_applet->size = panel_applet_get_size (gw_applet->applet);
-
     gw_applet->orient = panel_applet_get_orient (gw_applet->applet);
 
-    action_group = gtk_action_group_new ("GWeather Applet Actions");
-    gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-    gtk_action_group_add_actions (action_group,
-				  weather_applet_menu_actions,
-				  G_N_ELEMENTS (weather_applet_menu_actions),
-				  gw_applet);
+    action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 weather_applet_menu_actions,
+	                                 G_N_ELEMENTS (weather_applet_menu_actions),
+	                                 gw_applet);
     ui_path = g_build_filename (GWEATHER_MENU_UI_DIR, "gweather-applet-menu.xml", NULL);
     panel_applet_setup_menu_from_file (gw_applet->applet,
-				       ui_path, action_group);
+				       ui_path, action_group,
+				       GETTEXT_PACKAGE);
     g_free (ui_path);
 
-    if (panel_applet_get_locked_down (gw_applet->applet)) {
-	    GtkAction *action;
+	gtk_widget_insert_action_group (GTK_WIDGET (gw_applet->applet), "gweather",
+	                                G_ACTION_GROUP (action_group));
+
+    action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+	g_object_bind_property (gw_applet->applet, "locked-down", action, "enabled",
+				G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-	    action = gtk_action_group_get_action (action_group, "Props");
-	    gtk_action_set_visible (action, FALSE);
-    }
     g_object_unref (action_group);
 
     type = g_settings_get_boolean (gw_applet->applet_settings, "detailed") ?
@@ -379,9 +391,9 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 
     place_widgets(gw_applet);        
 
-#ifdef HAVE_NETWORKMANAGER
-    setup_network_monitor (gw_applet);     
-#endif
+    monitor = g_network_monitor_get_default();
+    g_signal_connect (monitor, "network-changed",
+                      G_CALLBACK (network_changed), gw_applet);
 }
 
 gint timeout_cb (gpointer data)
@@ -523,90 +535,3 @@ void gweather_update (GWeatherApplet *gw_applet)
     gweather_info_update (gw_applet->gweather_info);
 }
 
-#ifdef HAVE_NETWORKMANAGER
-static void
-state_notify (DBusPendingCall *pending, gpointer data)
-{
-	GWeatherApplet *gw_applet = data;
-
-        DBusMessage *msg = dbus_pending_call_steal_reply (pending);
-
-        if (!msg)
-                return;
-
-        if (dbus_message_get_type (msg) == DBUS_MESSAGE_TYPE_METHOD_RETURN) {
-                dbus_uint32_t result;
-
-                if (dbus_message_get_args (msg, NULL,
-                                           DBUS_TYPE_UINT32, &result,
-                                           DBUS_TYPE_INVALID)) {
-                        if (result == NM_STATE_CONNECTED) {
-				/* thank you, glibc */
-				res_init ();
-				gweather_update (gw_applet);
-                        }
-                }
-        }
-
-        dbus_message_unref (msg);
-}
-
-static void
-check_network (DBusConnection *connection, gpointer user_data)
-{
-        DBusMessage *message;
-        DBusPendingCall *reply;
-
-        message = dbus_message_new_method_call (NM_DBUS_SERVICE,
-                                                NM_DBUS_PATH,
-                                                NM_DBUS_INTERFACE,
-                                                "state");
-        if (dbus_connection_send_with_reply (connection, message, &reply, -1)) {
-                dbus_pending_call_set_notify (reply, state_notify, user_data, NULL);
-                dbus_pending_call_unref (reply);
-        }
-
-        dbus_message_unref (message);
-}
-
-static DBusHandlerResult
-filter_func (DBusConnection *connection, DBusMessage *message, void *user_data)
-{
-    if (dbus_message_is_signal (message, 
-				NM_DBUS_INTERFACE, 
-				"StateChanged")) {
-	check_network (connection, user_data);
-
-        return DBUS_HANDLER_RESULT_HANDLED;
-    }
-
-    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
-}
-
-static void
-setup_network_monitor (GWeatherApplet *gw_applet)
-{
-    GError *error;
-    static DBusGConnection *bus = NULL;
-    DBusConnection *dbus;
-
-    if (bus == NULL) {
-        error = NULL;
-        bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
-        if (bus == NULL) {
-            g_warning ("Couldn't connect to system bus: %s",
-                       error->message);
-            g_error_free (error);
-
-            return;
-        }
-
-        dbus = dbus_g_connection_get_connection (bus);	
-        dbus_connection_add_filter (dbus, filter_func, gw_applet, NULL);
-        dbus_bus_add_match (dbus,
-                            "type='signal',"
-                            "interface='" NM_DBUS_INTERFACE "'",
-                            NULL);
-    }
-}	
-#endif /* HAVE_NETWORKMANAGER */
